@@ -89,17 +89,16 @@ class DelimitEndpoints:
         response.raise_for_status()
         return response
 
-    def delimit_contract(self, employee_id, start_date, end_date):
+    def delimit_basic_pay(self, employee_id, start_date, end_date):
         """
-        Delimit positions in SAP
-        :param position_id: the ID of the organisational unit you want to delimit
+        Delimit the Basic Pay in SAP
+        :param employee_id: the AFAS Employee ID you want to delimit
         :param start_date: the start date of the record you want to delimit
         :param end_date: the end date at which the record will be delimit
-        :param workcenter: the workcenter you want to delimit
         :return: status
         """
         data_filter = f"Afasemployeenumber='{employee_id}',Startdate='{start_date}',Enddate='{end_date}'"
-        response = self.base_class.delete_data(uri="ContractElementDel", filter=data_filter)
+        response = self.base_class.delete_data(uri="BasicPayDel", filter=data_filter)
         response.raise_for_status()
         return response
 
